﻿using C1.WPF.RichTextBox;
using C1.WPF.RichTextBox.Documents;
using System;
using System.Collections.Generic;
using System.IO;
using System.Linq;
using System.Text;
using System.Threading.Tasks;
using System.Windows;
using System.Windows.Controls;
using System.Windows.Controls.Primitives;
using System.Windows.Data;
using System.Windows.Documents;
using System.Windows.Input;
using System.Windows.Media;
using System.Windows.Media.Imaging;
using System.Windows.Navigation;
using System.Windows.Shapes;
using System.Xml;

namespace RichTextBoxToolbar
{
    /// <summary>
    /// Interaction logic for MainWindow.xaml
    /// </summary>
    public partial class MainWindow : Window
    {
        ToolbarSetting setting;
        public MainWindow()
        {
            InitializeComponent();
            setting = new ToolbarSetting();
        }
        static string fileName = "ToolBar.xml";
        private void ToolBar_Loaded(object sender, RoutedEventArgs e)
        {
            C1RichTextBoxToolbar toolbar = sender as C1RichTextBoxToolbar;
            C1FontFamilyTool fontFamily = (C1FontFamilyTool)toolbar.Template.FindName("13_T", toolbar);
            C1FontSizeTool fontSize = (C1FontSizeTool)toolbar.Template.FindName("15_T", toolbar);
            C1LineSpacingTool lineSpacingTool = (C1LineSpacingTool)toolbar.Template.FindName("47_T", toolbar);


            toolbar.FontFamilies.Clear();
            foreach (var font in Fonts.SystemFontFamilies)
                toolbar.FontFamilies.Add(font);
            FetchSetting();
            fontFamily.Loaded += FontFamily_Loaded;
            fontSize.Loaded += FontSize_Loaded;          
            lineSpacingTool.Loaded += LineSpacingTool_Loaded;
        }

        private void LineSpacingTool_Loaded(object sender, RoutedEventArgs e)
        {
            var lineSpacingTool = (C1LineSpacingTool)sender;
            if(setting.SavedLineSpace!=null)
                lineSpacingTool.SelectedValue = Double.Parse(setting.SavedLineSpace);
        }

        private void FetchSetting()
        {
            try
            {
                using (StreamReader reader = File.OpenText(fileName))
                {
                    System.Xml.Serialization.XmlSerializer xml = new System.Xml.Serialization.XmlSerializer(typeof(ToolbarSetting));
                    setting = (ToolbarSetting)xml.Deserialize(reader);
                    reader.Close();
                }
            }
            catch (Exception ex)
            {
                
            }
        }

        private void FontSize_Loaded(object sender, RoutedEventArgs e)
        {
            var fontSize = (C1FontSizeTool)sender; 
            fontSize.SelectedValue = Double.Parse(setting.SavedFontSize);
        }

        private void FontFamily_Loaded(object sender, RoutedEventArgs e)
        {
            var fontFamily = (C1FontFamilyTool)sender;
            fontFamily.SelectedValue = new FontFamily(setting.SavedFontFamily);
        }
        private void Window_Closing(object sender, System.ComponentModel.CancelEventArgs e)
        {
            if(rtbToolbar.IsLoaded)
            {
                C1FontFamilyTool fontFamily = (C1FontFamilyTool)rtbToolbar.Template.FindName("13_T", rtbToolbar);
                C1FontSizeTool fontSize = (C1FontSizeTool)rtbToolbar.Template.FindName("15_T", rtbToolbar);
                C1LineSpacingTool lineSpacingTool = (C1LineSpacingTool)rtbToolbar.Template.FindName("47_T", rtbToolbar);

                using (XmlWriter writer = XmlWriter.Create(fileName))
                {
                    ToolbarSetting setting = new ToolbarSetting();
                    if(fontSize.SelectedValue!=null & fontFamily.SelectedValue!=null)
                    {
                        setting.SavedFontSize = fontSize.SelectedValue.ToString();
                        setting.SavedFontFamily = fontFamily.SelectedValue.ToString();
                        setting.SavedLineSpace = lineSpacingTool.SelectedValue.ToString();
                        System.Xml.Serialization.XmlSerializer xml = new System.Xml.Serialization.XmlSerializer(typeof(ToolbarSetting));
                        xml.Serialize(writer, setting);
                    }                    
                }
            }
        }
    }
}
